//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.plugin.alignment.commands;

import java.io.File;
import java.io.FilenameFilter;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.Level;

import de.ugoe.cs.autoquest.CommandHelpers;
import de.ugoe.cs.autoquest.eventcore.Event;
import de.ugoe.cs.autoquest.plugin.alignment.SmithWaterman;
import de.ugoe.cs.autoquest.plugin.alignment.DifferenceSubstitutionMatrix;
import de.ugoe.cs.autoquest.plugin.alignment.seqgen.RandomSequenceGenerator;
import de.ugoe.cs.util.console.Command;
import de.ugoe.cs.util.console.Console;
import de.ugoe.cs.util.console.GlobalDataContainer;

/**
 * <p>
 * Command to generate a binary alignment of two sequences
 * </p>
 * 
 * @author Steffen Herbold
 * @version 1.0
 */
public class CMDbinaryAlignment implements Command {

	/*
	 * (non-Javadoc)
	 * 
	 * @see de.ugoe.cs.util.console.Command#run(java.util.List)
	 */
	@Override
	public void run(List<Object> parameters) {
		String sequencesName;
		String algorithm;
		try {
			sequencesName = (String) parameters.get(0);
			if (parameters.size() > 1) {
				algorithm = (String) parameters.get(1);
			}
		} catch (Exception e) {
			throw new IllegalArgumentException();
		}

		Collection<List<Event>> sequences = new LinkedList<List<Event>>();
		sequences = (Collection<List<Event>>) GlobalDataContainer.getInstance()
				.getData(sequencesName);
		Console.println("Number of sequences: " + sequences.size());
		for (Iterator<List<Event>> it = sequences.iterator(); it.hasNext();) {
			List<Event> ev = it.next();
			RandomSequenceGenerator randgen = new RandomSequenceGenerator(1,
					80, 10);
			int[] seq1 = randgen.generate(ev);
			int[] seq2 = randgen.generate(ev);
			SmithWaterman sw = new SmithWaterman(seq1, seq2,
					new DifferenceSubstitutionMatrix(seq1, seq2));

			sw.printDPMatrix();
			Console.println("Number of events in sequence: " + ev.size());
			for (Iterator<Event> foo = ev.iterator(); foo.hasNext();) {
				Event blubb = foo.next();
				// Console.println(blubb.toString());
			}
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see de.ugoe.cs.util.console.Command#help()
	 */
	@Override
	public String help() {
		return "binaryAlignment <sequencesName> {<algorithm>}";
	}

}
